@@ -138,7 +138,10 @@ class GetLatestTinderbox(object):
     
     timestamp = timestamp or 0
     url = url or self.base_url
-    element = lxml.html.parse(url)
+    try:
+      element = lxml.html.parse(url)
+    except IOError:
+      raise NotFoundException("No builds found at %s" % url, url)
     links = element.xpath('//a[@href]')
     builds = {}
     url = url.rstrip('/')
@@ -188,7 +191,10 @@ class GetLatestTinderbox(object):
     if url is None:
       _builds = self.builds(url)
       url = _builds[sorted(_builds.keys(), reverse=True)[0]]
-    element = lxml.html.parse(url)
+    try:
+      element = lxml.html.parse(url)
+    except IOError:
+      raise NotFoundException("url %s not found" % url, url)
     links = element.xpath('//a[@href]')
     logs = {}
     regex = re.compile(self.log_regex())
